--[[

Game:	Farming Simulator 19
Title:	InfoMenu - UnitConvert Lite (InGameMenu)
Author:	ThundR

--]]

-- [Declarations] ***********************************************************************************************************************************

UnitExtension.InGameMenuMapFrame = {}
UnitExtension.InGameMenuPricesFrame = {}
UnitExtension.InGameMenuStatisticsFrame = {}

-- [Initialization] *********************************************************************************************************************************

function UnitExtension:initializeInGameMenu()
-- Initializes InGameMenu

	-- InGameMenuMapFrame overrides
	HMUtils.setFunction(self, "InGameMenuMapFrame", "onFrameOpen")
	HMUtils.setFunction(self, "InGameMenuMapFrame", "generateFarmlandOverlay")

	-- InGameMenuPricesFrame overrides
	HMUtils.setFunction(self, "InGameMenuPricesFrame", "updatePriceTable")

end

-- [InGameMenuMapFrame Overrides] *******************************************************************************************************************

function UnitExtension.InGameMenuMapFrame:onFrameOpen(...)
	local savedFunc = HMUtils.getSavedFunction(g_ucLite, "InGameMenuMapFrame.onFrameOpen")

	self.unitExtension = Utils.getNoNil(self.unitExtension, {})

	if not self.unitExtension.initialized then
		local farmlandBalanceParent = self.balanceText.parent
		local farmlandValueParent = self.farmlandValueText.parent
		local farmlandAreaElement = farmlandValueParent:clone(self.farmlandValueBox)
		local farmlandOwnerElement = farmlandValueParent:clone(self.farmlandValueBox)

		-- Owner element
		local parentX, parentY = HMUtils.unpack(farmlandBalanceParent.position)
		local parentWidth, parentHeight = HMUtils.unpack(farmlandBalanceParent.size)
		farmlandOwnerElement:updateScreenAlign("middleLeft")
		farmlandOwnerElement:updatePositionForOrigin("middleLeft")
		farmlandOwnerElement:setPosition(parentX, parentY + parentHeight)
		farmlandOwnerElement.elements[1]:setText(g_ucLite:getLocalText("ui_owner")..":")
		self.farmlandOwnerElement = farmlandOwnerElement
		self.farmlandOwnerText = farmlandOwnerElement.elements[2]

		-- Area element
		local parentX, parentY = HMUtils.unpack(farmlandValueParent.position)
		local parentWidth, parentHeight = HMUtils.unpack(farmlandValueParent.size)
		farmlandAreaElement:setPosition(parentX, parentY + parentHeight)
		farmlandAreaElement.elements[1]:setText(HMUtils.getText("ui_fieldArea")..":")
		self.farmlandAreaElement = farmlandAreaElement
		self.farmlandAreaText = farmlandAreaElement.elements[2]

		self.unitExtension.initialized = true
	end

	local ret = HMUtils.pack(savedFunc(self, ...))
	return HMUtils.unpack(ret)
end

function UnitExtension.InGameMenuMapFrame:generateFarmlandOverlay(...)
	local savedFunc = HMUtils.getSavedFunction(g_ucLite, "InGameMenuMapFrame.generateFarmlandOverlay")
	local ret = HMUtils.pack(savedFunc(self, ...))

	local ownerText = ""
	local areaText = "0"

	local selectedFarmland = self.selectedFarmland
	if selectedFarmland then
		local area = tonumber(selectedFarmland.areaInHa)
		local npcIndex = g_npcManager:getNPCByIndex(tonumber(selectedFarmland.npcIndex))

		if selectedFarmland.isOwned then
			ownerText = HMUtils.getText("ui_playerCharacter")
		elseif npcIndex then
			ownerText = npcIndex.title
		end

		if area then
			area = area  g_i18n:getArea(g_ucLite.areaScale)
			areaText = HMUtils.numToStr(area, 2, "ROUND")
		end
	end

	self.farmlandOwnerText:setText(ownerText)
	self.farmlandAreaText:setText(string.format("%s %s", areaText, g_i18n:getAreaUnit()))

	return HMUtils.unpack(ret)
end

-- [InGameMenuPricesFrame Overrides] ****************************************************************************************************************

function UnitExtension.InGameMenuPricesFrame:updatePriceTable(...)
	local savedFunc = HMUtils.getSavedFunction(g_ucLite, "InGameMenuPricesFrame.updatePriceTable")

	local pageTitleElement = self.mainBox.parent.elements[1].elements[2]

	-- Initialize prices menu
	if not self.ucInitialized then
		-- Create fill type name elements
		self.fillTypeNameHeaders = {}
		local tableHeaderBox = self.tableHeaderBox
		for i, element in ipairs(tableHeaderBox.elements) do
			if i > 1 then
				local fillTypeNameElement = TextElement:new(self)
				element:addElement(fillTypeNameElement)
				fillTypeNameElement:applyProfile("ingameMenuPriceRowSiloCapacityValue")
				table.insert(self.fillTypeNameHeaders, fillTypeNameElement)
			end
		end
		self.ucInitialized = true
	end

	local ret = HMUtils.pack(savedFunc(self, ...))

	local fillTypeNameHeaders = self.fillTypeNameHeaders
	local startFillType = self.startFillType

	for columnIdx = 1, self.MAX_NUM_FILLTYPES do
		local fillTypeIndex = startFillType + (columnIdx-1)
		local fillType = self.priceFillTypes[fillTypeIndex]

		local fillTypeNameHeader = fillTypeNameHeaders[columnIdx]
		if fillTypeNameHeader then
			if fillType then
				fillTypeNameHeader:setText(fillType.title) --(HMUtils.properCase(fillType.title))
				fillTypeNameHeader:setVisible(true)
			else
				fillTypeNameHeader:setText("")
				fillTypeNameHeader:setVisible(false)
			end
		end
	end
	return HMUtils.unpack(ret)
end
